Central limit theorem not applicable so use simulation to estimate confidence interval for evidence.
CI_gamma1_evidence(temperatures, y_log_lik_t_equals_1_traces,
confidence = 0.95, simulations = 1000)Numeric vector of temperatures of power posteriors. One chain will be created for each element of the vector at the corresponding temperature.
Numeric matrix of log probabilities of y at different temperatures (columns) in different iterations (rows).
Numeric value of statistical confidence with which returning interval should contain the true value.
Integer value of number of simulations to use in estimation of the confidence interval.
Confidence interval as numeric vector of length 2.