Learn R Programming

BeviMed (version 6.0)

extract_prob_association: Extract the posterior probability of association

Description

Get posterior probability of association as numeric value, or optionally as numeric vector of length two with probabilities broken down by mode of inheritance (by passing by_model=TRUE), from a BeviMed object.

Usage

extract_prob_association(x, by_model = FALSE)

Value

Probability values.

Arguments

x

Object of class BeviMed.

by_model

Logical value determining whether to return probabilities broken down by mode of inheritance.

See Also

prob_association, bevimed