Learn R Programming

BeviMed (version 3.0)

gamma1_evidence: Calculate marginal probability of observed case-control status under model gamma = 1

Description

Calculate marginal probability of observed case-control status under model gamma = 1

Usage

gamma1_evidence(y, G, min_ac = 1L, ...)

Arguments

y
Logical vector of case (TRUE) control (FALSE) status.
G
Integer matrix of variant counts per individual, one row per individual and one column per variant.
min_ac
Minimum allele count per individual to be considered to have a pathogenic combination of variants. '1' could correspond to a dominant inheritance hypothesis whereas '2' could correspond to a recessive inheritance hypothesis. Can either be an integer value (then used for all samples), or integer vector of length(y), useful for example when different samples have different ploidy.
...
Other arguments to pass to bevimed.