Learn R Programming

BeviMed (version 1.2)

lower_bound_P_v_by_direct_sum: Calculate marginal probability of observed genotypes under variant-level pathogenicity model by summing over marginals condintional on pathogenic variant combinations

Description

Calculate marginal probability of observed genotypes under variant-level pathogenicity model by summing over marginals condintional on pathogenic variant combinations

Usage

lower_bound_P_v_by_direct_sum(y, G, min_ac = 1, q_shape = c(2, 100),
  p_shape = c(10, 2), omega_shape = c(2, 9),
  sum_over_variants = 1:nrow(G))

Arguments

y
Logical vector of case (TRUE) control (FALSE) status.
G
Integer matrix of variant counts per individual, one column per individual and one row per variant.
min_ac
Minimum allele count per individual to be considered to have a pathogenic combination of variants. '1' could correspond to a dominant inheritance hypothesis whereas '2' could correspond to a recessive inheritance hypothesis.
q_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with non-pathogenic variant combinations (i.e. they have less than min_ac variants.
p_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with pathogenic variant combinations (i.e. they have at least min_ac variants.
omega_shape
Beta shape hyper-priors for prior on rate of pathogenicity amongst variants.
sum_over_variants
Subset of variants for whose power set to calculate the direct sum over.