Calculate log lower bound for marginal probability of data under model gamma = 1 by summing likelihood over pathogenic variant partitions.
lower_bound_gamma1_evidence(y, G, min_ac = 1L, by_term = FALSE,
tau_shape = c(1, 1), pi_shape = c(6, 1), omega_shape = c(2, 8),
sum_over_variants = seq(length.out = ncol(G)))Logical vector of case (TRUE) control (FALSE) status.
Integer matrix of variant counts per individual, one row per individual and one column per variant.
Numeric vector of length the same as y or length 1 (in which case it is repeated to make it the same length as y) giving the minimum number of alleles at pathogenic variant sites each individual requires in order to classify as having a `pathogenic allele configuration'. If For example, 1 could correspond to hypothesis of dominant inheritance hypothesis. If there are differences in ploidy between individuals in the locus, it is necessary to set it on an sample level basis - e.g. to incorporate information about gender if the locus lies on the X chromosome.
Calculate probability that individual terms are pathogenic conditional on model gamma=1.
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with non-pathogenic variant combinations (i.e. they have less than min_ac variants.
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with pathogenic variant combinations (i.e. they have at least min_ac variants.
Beta shape hyper-priors for prior on rate of pathogenicity amongst variants.
Subset of variants for whose power set to calculate the direct sum over.
Log of marginal likelihood.