Learn R Programming

BeviMed (version 1.2)

power_posteriors_ML_sum: Calculate the Marginal Likelihood under v by summation over power posterior likelihood exptectances

Description

Calculate the Marginal Likelihood under v by summation over power posterior likelihood exptectances

Usage

power_posteriors_ML_sum(y_log_lik_t_equals_1_traces, temperatures)

Arguments

y_log_lik_t_equals_1_traces
Numeric matrix of log probabilities of y at different temperatures (columns) in different iterations (rows).
temperatures
Numeric vector of temperatures used to produce y_log_lik_t_equals_1_traces.

Value

  • Numeric value of estimated log marginal likelihood.