Learn R Programming

BeviMed (version 6.0)

print.BeviMed: Print readable summary of BeviMed object

Description

Print summary statistics of BeviMed inference, including probability of association, probability of dominant inheritance given association and probability of pathogenicity of each variant under dominant and recessive inheritance.

Usage

# S3 method for BeviMed
print(x, ...)

Value

Prints a summary.

Arguments

x

BeviMed object.

...

Arguments passed to summary.BeviMed

See Also

summary.BeviMed