BeviMed_summary object.Print readable summary of BeviMed_summary object.
Print summary statistics of BeviMed inference, including probability of association, probability of dominant inheritance given association and probability of pathogenicity of each variant under dominant and recessive inheritance.
# S3 method for BeviMed_summary
print(x, print_prob_pathogenic = TRUE, ...)BeviMed_summary object.
Logical value indicating whether to print list of marginal probabilities of z_j = 1 for all variants j under each mode of inheritance.
Unused arguments
Prints a summary