Learn R Programming

BeviMed (version 3.0)

region_association_evidence: Calculate marginal probability of observed genotypes under 'pathogenic region' model

Description

Marginal probability calculated exactly by integration.

Usage

region_association_evidence(y, G, min_ac = 1L, tau_shape = c(1, 1),
  pi_shape = c(2, 1))

Arguments

y
Logical vector of case (TRUE) control (FALSE) status.
G
Integer/logical vector of genotypes by individual corresponding to case-control label y giving the 'rare variant counts'/'presence of rare variant indicators'.
min_ac
Minimum allele count per individual to be considered to have a pathogenic combination of variants. '1' could correspond to a dominant inheritance hypothesis whereas '2' could correspond to a recessive inheritance hypothesis. Can either be an integer value (then used for all samples), or integer vector of length(y), useful for example when different samples have different ploidy.
tau_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with non-pathogenic variant combinations (i.e. they have less than min_ac variants.
pi_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with pathogenic variant combinations (i.e. they have at least min_ac variants.