Tune the proposal standard deviations for the Metropolis-Hastings updates of either phi or omega
tune_proposal_sds(
tune_for = c("logit_omega"),
initial_proposal_sds,
target_acceptance_range = c(0.3, 0.7),
other_param_proposal_sd = 0.7,
max_tuning_cycles = 10,
initial_rate = 1,
rate_decay = 1.2,
verbose = FALSE,
...
)Numeric vector of proposal SDs for the different temperature chains.
Character vector of length one, naming which variable to tune the proposal SDs for: either "logit_omega" or "log_phi".
Numeric vector with the initial values of the proposal SDs.
Numeric vector of length 2 where the first element is the lower bound for the acceptance interval and the second is the upper bound.
The proposal SD to use for log_phi when tuning logit_omega or vice versa.
Maximum number of tuning cycles to perform before returning the proposal SDs as they are.
Initial rate at which to mutate the proposal SDs.
Geometric rate of decay for size of proposal SD mutation with each successive tuning cycle.
To print execution progress or not.
Other arguments to be passed to call_cpp.