Learn R Programming

BeviMed (version 3.0)

tune_temperatures: Tune temperatures using interval bisection to minimimise Kullback-Liebler divergence between adjacent power posteriors

Description

Tune temperatures using interval bisection to minimimise Kullback-Liebler divergence between adjacent power posteriors

Usage

tune_temperatures(number_of_temperatures, return_temperatures = FALSE, ...)

Arguments

number_of_temperatures
Integer value giving number of tuned temperatures (including 0 and 1) to obtain.
return_temperatures
Logical value determining whether to return just the numeric vector of tuned temperatures or to return the BeviMed-classed object containing the output of the MCMC sampling.
...
Other arguments to pass to call_cpp.

Value

If return_temperatures == TRUE, a numeric vector of tuned temperatures, otherwise an object of class BeviMed.