Learn R Programming

BeviMed (version 3.0)

lower_bound_gamma1_evidence: Calculate log lower bound for marginal probability of observations under model gamma = 1 by summing likelihood over pathogenic variant (z) configurations, or probabilities that individual variants are pathogenic.

Description

Calculate log lower bound for marginal probability of observations under model gamma = 1 by summing likelihood over pathogenic variant (z) configurations, or probabilities that individual variants are pathogenic.

Usage

lower_bound_gamma1_evidence(y, G, min_ac = 1L, by_term = FALSE,
  tau_shape = c(1, 1), pi_shape = c(6, 1), omega_shape = c(2, 8),
  sum_over_variants = seq(ncol(G)))

Arguments

y
Logical vector of case (TRUE) control (FALSE) status.
G
Integer matrix of variant counts per individual, one row per individual and one column per variant.
min_ac
Minimum allele count per individual to be considered to have a pathogenic combination of variants. '1' could correspond to a dominant inheritance hypothesis whereas '2' could correspond to a recessive inheritance hypothesis. Can either be an integer value (then used for all samples), or integer vector of length(y), useful for example when different samples have different ploidy.
by_term
Calculate probability that individual terms are pathogenic conditional on model gamma=1.
tau_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with non-pathogenic variant combinations (i.e. they have less than min_ac variants.
pi_shape
Beta shape hyper-priors for prior on rate of affection (i.e. being a case) amongst individuals with pathogenic variant combinations (i.e. they have at least min_ac variants.
omega_shape
Beta shape hyper-priors for prior on rate of pathogenicity amongst variants.
sum_over_variants
Subset of variants for whose power set to calculate the direct sum over.