Learn R Programming

BeviMed (version 5.3)

print.BeviMed: Print readable summary of BeviMed object

Description

Print summary statistics of BeviMed inference, including probability of association, probability of dominant inheritance given association and probability of pathogenicity of each variant under dominant and recessive inheritance.

Usage

# S3 method for BeviMed
print(x, ...)

Arguments

x

BeviMed object.

...

Arguments passed to summary.BeviMed

Value

Prints a summary.

See Also

summary.BeviMed