Equivalent to prob_association where the prior probability of one mode of inheritance is 1. This function is faster, as it only calls bevimed_m once.
prob_association_m(y, min_ac = 1L, prior_prob_association = 0.01, ...)Logical vector of case (TRUE) control (FALSE) status.
Numeric vector of length the same as y or length 1 (in which case it is repeated to make it the same length as y) giving the minimum number of alleles at pathogenic variant sites each individual requires in order to classify as having a `pathogenic allele configuration'. If For example, 1 could correspond to hypothesis of dominant inheritance hypothesis. If there are differences in ploidy between individuals in the locus, it is necessary to set it on an sample level basis - e.g. to incorporate information about gender if the locus lies on the X chromosome.
The prior probability of association.
Other arguments to pass to log_BF.
Probability value.