Learn R Programming

BeviMed (version 3.0)

tune_proposal_sds: Tune the proposal standard deviations for the Metropolis-Hastings updates of either phi or omega

Description

Tune the proposal standard deviations for the Metropolis-Hastings updates of either phi or omega

Usage

tune_proposal_sds(tune_for = c("logit_omega", "log_phi"),
  initial_proposal_sds, target_acceptance_range = c(0.3, 0.7),
  other_param_proposal_sd = 0.7, max_tuning_cycles = 10, initial_rate = 1,
  rate_decay = 1.2, verbose = FALSE, ...)

Arguments

tune_for
Character vector, where only the first element is used, determining which variable to tune the proposal SDs for.
initial_proposal_sds
Numeric vector with the initial values of the proposal SDs.
target_acceptance_range
Numeric vector of length 2 where the first element is the lower bound for the acceptance interval and the second is the upper bound.
other_param_proposal_sd
The proposal SD to use for log_phi when tuning logit_omega or vice versa.
max_tuning_cycles
Maximum number of tuning cycles to perform before returning the proposal SDs as they are.
initial_rate
Initial rate at which to mutate the proposal SDs.
rate_decay
Geometric rate of decay for size of proposal SD mutation with each successive tuning cycle.
verbose
To print execution progress or not.
...
Other arguments to be passed to call_cpp.

Value

Numeric vector of proposal SDs for the different temperature chains.